<?php
define('WP_CACHE', true); // WP-Optimize Cache
/**
 * The base configuration for WordPress
 *
 * The wp-config.php creation script uses this file during the installation.
 * You don't have to use the web site, you can copy this file to "wp-config.php"
 * and fill in the values.
 *
 * This file contains the following configurations:
 *
 * * Database settings
 * * Secret keys
 * * Database table prefix
 * * ABSPATH
 *
 * @link https://wordpress.org/documentation/article/editing-wp-config-php/
 *
 * @package WordPress
 */
// ** Database settings - You can get this info from your web host ** //
/** The name of the database for WordPress */
define( 'DB_NAME', 'vrclvilv_wp665' );
/** Database username */
define( 'DB_USER', 'vrclvilv_wp665' );
/** Database password */
define( 'DB_PASSWORD', 'St]p)gDP]2](93nx' );
/** Database hostname */
define( 'DB_HOST', 'localhost' );
/** Database charset to use in creating database tables. */
define( 'DB_CHARSET', 'utf8' );
/** The database collate type. Don't change this if in doubt. */
define( 'DB_COLLATE', '' );
/**#@+
 * Authentication unique keys and salts.
 *
 * Change these to different unique phrases! You can generate these using
 * the {@link https://api.wordpress.org/secret-key/1.1/salt/ WordPress.org secret-key service}.
 *
 * You can change these at any point in time to invalidate all existing cookies.
 * This will force all users to have to log in again.
 *
 * @since 2.6.0
 */
define( 'AUTH_KEY',         'aendaifqsbkitairb2tzczz8i4oadxqhkduzv3aayozrwy7apuembwlozc5pjxuy' );
define( 'SECURE_AUTH_KEY',  'lps9zfygtpwyozm4mxlrutlg7yt1whhq6nqfqine0fterp0scnsgk4vskcngxez9' );
define( 'LOGGED_IN_KEY',    'udkuxcxuewzcncotif7t3ylz2fswnahzocdlfuukwthmec45hq8rhlk8ebgghepv' );
define( 'NONCE_KEY',        '5spb2pvqhlavaaczdcaul95mrnqpwxnmb9qwnpbftj1vep5kcmasdgugktgsqusz' );
define( 'AUTH_SALT',        'ldwopgzhbvvsctdda8fvco7edbi5537rg00jgsvewnvzumyfoxpixfahhfs1zq1d' );
define( 'SECURE_AUTH_SALT', 'c9nksz72ymdwx33fmchx86grkzrylnggtxrzgignqndzvlvcrzcvu6hnqy2h6jjl' );
define( 'LOGGED_IN_SALT',   'sm3oos2ux0ztohtnnjdruds2dgcxqdfsvfhpxh4vdqrun9xkqh2see2yfeflncsb' );
define( 'NONCE_SALT',       '8prgvh1fgn8sixuewpfe4feczedna4vfrmccm0thshzjnuikabdg4irhnk0urfjf' );
/**#@-*/
/**
 * WordPress database table prefix.
 *
 * You can have multiple installations in one database if you give each
 * a unique prefix. Only numbers, letters, and underscores please!
 */
$table_prefix = 'wpxl_';
/**
 * For developers: WordPress debugging mode.
 *
 * Change this to true to enable the display of notices during development.
 * It is strongly recommended that plugin and theme developers use WP_DEBUG
 * in their development environments.
 *
 * For information on other constants that can be used for debugging,
 * visit the documentation.
 *
 * @link https://wordpress.org/documentation/article/debugging-in-wordpress/
 */
define( 'WP_DEBUG', false );
/* Add any custom values between this line and the "stop editing" line. */
/* That's all, stop editing! Happy publishing. */
/** Absolute path to the WordPress directory. */
if ( ! defined( 'ABSPATH' ) ) {
	define( 'ABSPATH', __DIR__ . '/' );
}
/** Sets up WordPress vars and included files. */
require_once ABSPATH . 'wp-settings.php';